@@ -381,15 +381,15 @@ import traceback
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Type
 
-from ae.core import DEBUG_LEVELS, stack_var                         # type: ignore
 from ae.updater import check_all                                    # type: ignore
-from ae.console import ConsoleApp                                   # type: ignore
-
+from ae.inspector import stack_var                                  # type: ignore
 from ae.files import FilesRegister, RegisteredFile                  # type: ignore
 from ae.i18n import default_language                                # type: ignore
+from ae.core import DEBUG_LEVELS                                    # type: ignore
+from ae.console import ConsoleApp                                   # type: ignore
 
 
-__version__ = '0.0.30'
+__version__ = '0.0.31'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
